@@ -7,7 +7,7 @@ use LWP::UserAgent;
 use XML::Liberal;
 use XML::LibXML;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.1.0';
 
 sub new {
     my $class = shift;
@@ -23,13 +23,14 @@ sub new {
 
 sub logon {
     my $self = shift;
-    my $res = $self->{ua}->get($self->{base_url}
-                               . '?cmd=logon'
-                               . '&email=' . $self->{email}
-                               . '&password=' . $self->{password});
-    if ($self->_is_error($res->content)) {
-        return;
-    }
+    my $res = $self->{ua}->get(
+        $self->{base_url}
+        . '?cmd=logon'
+        . '&email=' . $self->{email}
+        . '&password=' . $self->{password});
+
+    return  if ($self->_is_error($res->content));
+    
     my $doc = $self->{parser}->parse_string($res->content);
     $self->{token} = $doc->findvalue("//*[local-name()='response']/*[local-name()='token']/text()");
     return $self->{token};
@@ -37,12 +38,13 @@ sub logon {
 
 sub logoff {
     my $self = shift;
-    my $res = $self->{ua}->get($self->{base_url}
-                               . '?cmd=logoff'
-                               . '&token=' . $self->{token});
-    if ($self->_is_error($res->content)) {
-        return;
-    }
+    my $res = $self->{ua}->get(
+        $self->{base_url}
+        . '?cmd=logoff'
+        . '&token=' . $self->{token});
+
+    return  if ($self->_is_error($res->content));
+
     delete $self->{token};
     return;
 }
@@ -51,13 +53,14 @@ sub request_method {
     my $self = shift;
     my ($cmd, $param) = @_;
     my $query = join('', map {'&' . $_ . '=' . $param->{$_}} keys(%$param));
-    my $res = $self->{ua}->get($self->{base_url}
-                               . '?cmd=' . $cmd
-                               . '&token=' . $self->{token}
-                               . $query);
-    if ($self->_is_error($res->content)) {
-        return;
-    }
+    my $res = $self->{ua}->get(
+        $self->{base_url}
+        . '?cmd=' . $cmd
+        . '&token=' . $self->{token}
+        . $query);
+
+    return  if ($self->_is_error($res->content));
+
     return $res->content;
 }
 
@@ -66,10 +69,8 @@ sub _is_error {
     my ($content)  = @_;
     $content =~ s/<\?xml\s+.*?\?>//g;
     my $doc  = $self->{parser}->parse_string($content);
-    $self->{error}{code}
-        = $doc->findvalue("//*[local-name()='response']/*[local-name()='error']/\@code");
-    $self->{error}{msg}
-        = $doc->findvalue("//*[local-name()='response']/*[local-name()='error']/text()");
+    $self->{error}{code} = $doc->findvalue("//*[local-name()='response']/*[local-name()='error']/\@code");
+    $self->{error}{msg}  = $doc->findvalue("//*[local-name()='response']/*[local-name()='error']/text()");
     return $self->{error}{code} ? '1' : '0';
 }
 
@@ -79,7 +80,7 @@ __END__
 
 =head1 NAME
 
-WebService::FogBugz - Perl interface to the FogBugz API
+WebService::FogBugz - FogBugz API for Perl
 
 =head1 SYNOPSIS
 
@@ -102,29 +103,55 @@ WebService::FogBugz - Perl interface to the FogBugz API
 
 =head1 DESCRIPTION
 
-This module provides you Perl interface for FogBugz API.
-FogBugz is a project management system.
+This module provides a Perl interface for the FogBugz API. FogBugz is a 
+project management system.
 
 =head1 METHODS
 
 =head2 new([%options])
-this method returns an instance of this module.
-and this method allows following arguments;
-- email (almost your email address for log in to FogBugz)
-- password
-- base_url (your fogbugz api's URL.Probably http://www.example.com/fogbugz/api.asp. For example, if the URL is http://www.example.com/fogbugz, hit http://www.example.com/fogbugz/api.xml.And see the url field of response xml.)
+
+This method returns an instance of this module. 
+
+The arguments hash must provide the following parameters:
+
+=over
+
+=item * email
+
+Your login email address used for logging in to FogBugz.
+
+=item * password
+
+=item * base_url
+
+Your FogBugz API's URL. This may be a hosted instance 
+(e.g. https://example.fogbugz.com/api.asp?) or a local installation
+(e.g. http://www.example.com/fogbugz/api.asp).
+
+If you're unsure about your base_url, check the url field of an XML request.
+For example, if using a local installation, such as 
+http://www.example.com/fogbugz, check the URL as 
+http://www.example.com/fogbugz/api.xml. If you have a FogBugz On Demand account
+the link will be https://example.fogbugz.com/api.xml, where example is your 
+account name.
+
+=back
 
 =head2 logon
+
 Retrieves an API token from Fogbugz.
 
 =head2 logoff
+
 Log off from FogBugz.
 
-=head2 request_method
-the 1st argument is name of command.
-FogBugz 6.0 supports many commands. You will find from FogBugz Online Documantation by using keyword of 'cmd'.
+=head2 request_method($command,$hash)
 
-the 2nd argument is parameters of command of 1st argument.
+The 1st argument is name of command, the 2nd argument is the hash of parameters
+for the specified command.
+
+FogBugz supports many commands. You will find from FogBugz Online Documantation
+by using keyword of 'cmd'.
 
 =head1 BUGS
 
@@ -142,9 +169,13 @@ You can also look for information at:
 
 =over 4
 
-=item * FogBugz Online Documentation - API 
+=item * FogBugz Online Documentation
 
-L<http://www.fogcreek.com/FogBugz/docs/60/topics/advanced/API.html>
+L<http://help.fogcreek.com/fogbugz>
+
+=item * FogBugz Online Documentation - API
+
+L<http://help.fogcreek.com/8202/xml-api>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -164,17 +195,17 @@ L<http://search.cpan.org/dist/WebService-FogBugz>
 
 =back
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-L<http://www.fogcreek.com/FogBugz/docs/60/topics/advanced/API.html>
+Original Author: Takatsugu Shigeta  C<< <shigeta@cpan.org> >>
 
-=head1 AUTHOR
-
-Takatsugu Shigeta  C<< <takatsugu.shigeta@gmail.com> >>
+Current Maintainer: Barbie  C<< <barbie@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007, Takatsugu Shigeta C<< <takatsugu.shigeta@gmail.com> >>. All rights reserved.
+  Copyright (c) 2007-2014, Takatsugu Shigeta C<< <shigeta@cpan.org> >>.
+  Copyright (c) 2014-2015, Barbie for Miss Barbell Productions. 
+  All rights reserved.
 
-This module is free software; you can redistribute it and/or
+This distribution is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
